#
# spec file for package python-param
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-param
Version:        1.9.3
Release:        bp155.2.14
Summary:        Declarative Python programming using Parameters
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://param.pyviz.org/
Source0:        https://github.com/ioam/param/archive/v%{version}.tar.gz
Source100:      python-param-rpmlintrc
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-numpy
BuildArch:      noarch
%python_subpackages

%description
Param is a library providing Parameters: Python attributes extended to
have features such as type and range checking, dynamically generated
values, documentation strings, default values, etc., each of which is
inherited from parent classes if not specified in a subclass.

Param contains only two required Python files, with no external
dependencies, and is provided freely for both non-commercial and
commercial use under a BSD license, so that it can easily be included
as part of other projects.

%prep
%setup -q -n param-%{version}
sed -i -e 's:version=get_setup_version("param"):version="%{version}":g' setup.py
echo '{"git_describe": "v%{version}", "version_string": "%{version}"}' > param/.version

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand nosetests-%{$python_bin_suffix}

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/param/
%{python_sitelib}/numbergen/
%{python_sitelib}/param-%{version}-py*.egg-info

%changelog
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.9.3
  * Removed outdated warning message
  * Internal removal of old API usage
* Wed Jan 22 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 1.9.2:
  * No upstream changelog
* Fri Aug 30 2019 Todd R <toddrme2178@gmail.com>
- Include a .version file.  Other packages need this to determine
  this package's version.
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.1:
  * No upstream changelog
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 1.9.0
  New features:
    Added support for instance parameters, allowing parameter metadata
    to be modified per instance and allowing parameter objects to be
    passed to Panel objects (#306)
    Added label slot to Parameter, to allow overriding attribute name
    for display (#319)
    Added step slot to Parameter, e.g. to control Panel widget step
    size (#326)
    Added keywords_to_params utility for deducing Parameter types and
    ranges automatically (#317)
    Added support for multiple outputs from a Parameterized (#312)
    Added Selector as a more user-friendly version of ObjectSelector,
    accepting a list of options as a positional argument (#316)
  Changes affecting backwards compatibility:
    Changed from root logger to a param-specific logger; no change to
    API but will change format of error and warning messages (#330)
    Old abstract class Selector renamed to SelectorBase; should be no
    change unless user code added custom classes inherited from
    Selector without providing a constructor (#316)
  Bugfixes and other improvements:
    Various bugfixes (#320, #323, #327, #329)
    Other improvements (#315, #325)
* Wed Mar 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.2:
  * Added output decorator and outputs lookup method (#299, #312)
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- update to version 1.8.1
  * Added positional default arguments for nearly all Parameter
    subclasses (apart from ClassSelector)
  * Minor bugfixes for watching callbacks
- update to version 1.8.0
  * Parameterized methods can now declare @depends(p,q) to indicate
    that they depend on parameters p and q (defaulting to all
    parameters)
  * Parameterized methods can depend on subobjects with
    @depends(p.param,q.param.r), where p.param indicates
    dependencies on all parameters of p and q.param.r indicates a
    dependency on parameter r of q.
  * Functions and methods can watch parameter values, re-running
    when those values change or when an explicit trigger is issued,
    and can unwatch them later if needed.
  * Multiple events can be batched to trigger callbacks only once
    for a coordinated set of changes
  * Added support in ObjectSelector for selecting lists and dicts
    (#268)
  * Added pandas DataFrame and Series parameter types (#285)
  * Added support for regular expression validation to String
    Parameter (#241, #245)
* Tue Jul 17 2018 tchvatal@suse.com
- Switch to github tarball and enable tests.
* Mon Jul 16 2018 arun@gmx.de
- specfile:
  * remove devel requirement
- update to version 1.7.0:
  * A new param namespace object, which in future will allow
    subclasses of Parameterized to have much cleaner namespaces
    (#230).
  * Started testing on python 3.7-dev (#223).
  * param.version now provides functions to simplify dependants'
    setup.py/setup.cfg files (see pyviz/autover#49).
* Fri May 11 2018 arun@gmx.de
- update to version 1.6.1:
  * Restores support for the previous versioning system (pre 1.6; see
    [#225]), and fixes a number of issues with the new versioning
    system:
    + Allow package name to differ from repository name
    (pyviz/autover#39)
    + Allow develop install to work when repository is dirty
    (pyviz/autover#41)
    + Fixed failure to report dirty when commit count is 0
    (pyviz/autover#44)
* Wed Apr 18 2018 toddrme2178@gmail.com
- Update to version 1.6.0
  * Drop Cython build
* Thu Aug 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 1.5.1
  * Fixed error messages for ClassSelector with tuple of classes
  * Added get and contains methods for ParamOverrides
- Update to version 1.5.0
  * Added Range, Color, and Date parameters
  * Improved ObjectSelector error messages
  * Minor bugfixes
* Tue Oct 25 2016 toddrme2178@gmail.com
- Update to version 1.4.2:
  * Improved version reporting from version module
  * Minor bugfixes
- update to version 1.4.1:
  * Changed Selector parameters to respect order of provided options
  * Allow softbounds to be accessed like an attribute
- update to version 1.4.0:
  * Improved import ordering in parameterized.py
  * Fixed problematic travis shield link
  * Added 1.3.2 release notes
  * Add pypy to .travis.yml
  * Updated badge definitions to point to working URLS
  * Added optional support for setuptools in setup.py
  * Removed out-of-date pyflakes ignore (imports are used).  69d00b5
  * Added flake8 to travis config (and for now, output does not affect...
  * flake8: ignore rule about white space after comma
  * Fixed the 'python versions' shield.
  * Enabled cythonizing of param modules if Cython is available
  * Removed testing of Python 3.2 from travis.yml
  * Added shared_parameters context manager
  * Added unit test for shared_parameters context manager
  * Skip processing non-parameterized classes in setup_param
  * Update index.rst
  * Fixed formatting in docs
  * Fixed date in docs
  * Fixed typo in docs
  * Cleaned up get_range 6942b4f
  * Fixed formatting of print_param_defaults under Python2.7 and
    Python3
  * Added new Parameter types from the paramnb project
  * Fixed previous commit for Python2.6 compatibility
  * Fixed tests for python2.6 compatibility
  * commit_count can now be set via the Version constructor
  * Updated docstring of param.Version constructor
* Fri Jul 10 2015 toddrme2178@gmail.com
- update to version 1.3.2:
  * Updated unit test of ParamPager in the param IPython extension
  * Suppressing default parameter object names from the ParamPager
    title
  * Made _get_param_info and _param_docstrings methods of Pager public
  * Unicode support for param.String
  * Added shield displaying all supported Python versions
  * Added check for default value of String
  * Minor fix to logging: python loggers can accept keyword arguments.
  * Fixed Pyflakes errors
  * Fixed trailing whitespaces
* Fri Apr 10 2015 toddrme2178@gmail.com
- update to version 1.3.1:
  * Minor bugfix release to restore pre-1.3.0 script_repr behavior
    (accidentally changed in 1.3.0) and to fix issues with logging.
  * Param’s logging interface now matches that of Python’s logging
    module, making it simpler to use logging (see Python’s logging
    module for details). Note therefore that Param’s logging methods
    (a) no longer call functions that are passed as arguments
    (instead, Python’s logging module does lazy string merges), and
    (b) no longer automatically combine strings passed as arguments
    (instead, Python’s logging module supports string formatting).
- update to version 1.3.0:
  * Added ‘allow_None’ support to all Parameters. Any subclass of
    Parameter that checks types and/or values should be modified to
    add appropriate handling of allow_None.
  * Improved pretty printing (script_repr) of Parameterized instances,
    and made available via the pprint method. The script_repr name
    will be removed in a future release.
  * Added (reproducible) time-dependent random streams
    (numbergen.TimeAwareRandomState).
  * Added label and unit parameters to param.Time class.
  * Improved optional IPython extension.
* Mon Jul 14 2014 toddrme2178@gmail.com
- Initial version
